@@ -3,11 +3,12 @@ from typing import List, Union, Dict, Optional
 
 from slapp_py.core_classes.friend_code import FriendCode
 from slapp_py.core_classes.simple_source import SimpleSource
-from slapp_py.helpers.dict_helper import first_key
+from slapp_py.helpers.dict_helper import first_key, order_dict_by_value
 
 
 class FriendCodeHandler:
     _codes: Dict[FriendCode, List[SimpleSource]]
+    _ordered: bool = False
 
     def __init__(self, codes: Optional[Dict[FriendCode, List[SimpleSource]]] = None):
         self._codes = codes or {}
@@ -16,12 +17,20 @@ class FriendCodeHandler:
     def count(self):
         return len(self._codes)
 
+    @property
+    def current_code(self):
+        """Get the latest friend code in this information, or None."""
+        if not self._ordered:
+            self._order_codes()
+        return first_key(self._codes, None)
+
     def add(self, incoming: Union[FriendCode, List[FriendCode]], sources: Union[SimpleSource, List[SimpleSource]]):
         if not incoming or not sources:
             return
         if not isinstance(incoming, list):
             incoming = [incoming]
 
+        self._ordered = False
         for to_add in incoming:
             if to_add.no_code:
                 continue
@@ -48,10 +57,20 @@ class FriendCodeHandler:
         """Get the codes without the sources."""
         return list(self._codes.keys())
 
+    def get_codes_ordered(self):
+        """Get the codes without the sources in chronological order from most recent."""
+        if not self._ordered:
+            self._order_codes()
+        return self.get_codes_unordered()
+
     def get_codes_sourced(self) -> Dict[FriendCode, List[SimpleSource]]:
         """Get the codes with sources."""
         return {k: v for k, v in self._codes.items()}
 
+    def _order_codes(self):
+        self._codes = order_dict_by_value(self._codes, reverse=True)
+        self._ordered = True
+
     @staticmethod
     def from_dict(obj: dict) -> 'FriendCodeHandler':
         assert isinstance(obj, dict)
