@@ -3,11 +3,12 @@ from typing import List, Union, Dict, Optional
 from uuid import UUID
 
 from slapp_py.core_classes.simple_source import SimpleSource
-from slapp_py.helpers.dict_helper import first_key
+from slapp_py.helpers.dict_helper import first_key, order_dict_by_value
 
 
 class TeamsHandler:
     _teams: Dict[UUID, List[SimpleSource]]
+    _ordered: bool = False
 
     def __init__(self, teams: Optional[Dict[UUID, List[SimpleSource]]] = None):
         self._teams = teams or {}
@@ -18,7 +19,9 @@ class TeamsHandler:
 
     @property
     def current_team(self) -> UUID:
-        """Get the current team by getting the first key. Ideally, this is checked against the source..."""
+        """Get the current team in the Teams in this information."""
+        if not self._ordered:
+            self._order_teams()
         from slapp_py.core_classes.builtins import UnknownTeam
         return first_key(self._teams, UnknownTeam.guid)
 
@@ -28,6 +31,7 @@ class TeamsHandler:
         if not isinstance(incoming, list):
             incoming = [incoming]
 
+        self._ordered = False
         for to_add in incoming:
             self._teams.setdefault(to_add, []).extend(SimpleSource.from_serialized(sources))
 
@@ -52,10 +56,20 @@ class TeamsHandler:
         """Get the teams without the sources."""
         return list(self._teams.keys())
 
+    def get_teams_ordered(self):
+        """Get the teams without the sources in chronological order from most recent."""
+        if not self._ordered:
+            self._order_teams()
+        return self.get_teams_unordered()
+
     def get_teams_sourced(self) -> Dict[UUID, List[SimpleSource]]:
-        """Get the divisions with sources."""
+        """Get the teams with sources."""
         return {k: v for k, v in self._teams.items()}
 
+    def _order_teams(self):
+        self._teams = order_dict_by_value(self._teams, reverse=True)
+        self._ordered = True
+
     @staticmethod
     def from_dict(obj: dict) -> 'TeamsHandler':
         assert isinstance(obj, dict)
